==> haskell-libffi-0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libffi
version:              0.1
visibility:           public
id:                   libffi-0.1-6JV49STIEUfA7HvLqLSQvL
key:                  libffi-0.1-6JV49STIEUfA7HvLqLSQvL
license:              BSD-3-Clause
copyright:            Remi Turk 2008-2009
maintainer:           remi.turk@gmail.com
author:               Remi Turk
stability:            alpha
synopsis:             A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.

category:             Foreign
abi:                  9de6bc21040eaceb7ba6f4afef58e90b
exposed:              True
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/libffi-0.1
library-dirs:
    /usr/lib/ghc-9.0.1/site-local/libffi-0.1 /usr/lib/../lib

dynamic-library-dirs: /usr/lib /usr/lib/../lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/libffi-0.1
hs-libraries:         HSlibffi-0.1-6JV49STIEUfA7HvLqLSQvL
extra-libraries:      ffi ffi
includes:             ffi.h ffitarget.h
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html:         /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libffi-0.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libffi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libffi
version:              0.1
visibility:           public
id:                   libffi-0.1-6JV49STIEUfA7HvLqLSQvL
key:                  libffi-0.1-6JV49STIEUfA7HvLqLSQvL
license:              BSD-3-Clause
copyright:            Remi Turk 2008-2009
maintainer:           remi.turk@gmail.com
author:               Remi Turk
stability:            alpha
synopsis:             A binding to libffi
description:
    A binding to libffi, allowing C functions of types only known at runtime to be called from Haskell.

category:             Foreign
abi:                  15c8b4105d9747ce8c6605e09ddb5535
exposed:              True
exposed-modules:
    Foreign.LibFFI Foreign.LibFFI.Base Foreign.LibFFI.FFITypes
    Foreign.LibFFI.Internal Foreign.LibFFI.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/libffi-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/libffi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/libffi-0.1
hs-libraries:         HSlibffi-0.1-6JV49STIEUfA7HvLqLSQvL
extra-libraries:      ffi ffi
includes:             ffi.h ffitarget.h
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-libffi/html/libffi.haddock
haddock-html:         /usr/share/doc/haskell-libffi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
